package spider;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;
import java.net.*;

public class SpiderFrame extends Frame implements ActionListener{

private Button goButton, quitButton;
private TextArea messages, changedLinks;
private TextField currentChecking;
private Label messagesLabel, changedLabel;
private Panel topPanel, middlePanel, bottomPanel;
private LinkInformation[] linkHolder;
private int linkCount;
private FileReader fr;
private FileWriter fw;


public SpiderFrame(String title)
{
   //******************************************************************************
   //Code which just sets up visual objects, ignore until the next row of asterisks
   super(title);
   linkHolder = new LinkInformation [100];
   linkCount =0;
   topPanel = new Panel();
   bottomPanel = new Panel();
   middlePanel = new Panel();
   this.setLayout(new BorderLayout(3,1));
   messagesLabel = new Label("Messages     ");
   messages = new TextArea(10,30);
   topPanel.add(messagesLabel);
   topPanel.add(messages);
   add(BorderLayout.EAST, topPanel);
   changedLabel = new Label("Changed Links");
   changedLinks = new TextArea(10,30);
   middlePanel.add(changedLabel);
   middlePanel.add(changedLinks);
   add(BorderLayout.WEST, middlePanel);
   goButton = new Button("Check Links");
   quitButton = new Button("Quit");
   currentChecking = new TextField(30);
   bottomPanel.add(goButton);
   bottomPanel.add(quitButton);
   bottomPanel.add(currentChecking);
   add(BorderLayout.NORTH,bottomPanel);
   goButton.addActionListener(this);
   quitButton.addActionListener(this);
   //***************************************************************************
   try
   {
      //Read in the file of details of links. Each line consists
      //of the URL, a descriuption of the site and the time last
      //modified. Each is seperated by an asterisk
      File detailsFile = new File("links.txt");
      fr = new FileReader(detailsFile);
      BufferedReader br = new BufferedReader(fr);
      String rd;
      int count =0;
      //Read each line of links.txt
      while((rd =br.readLine())!=null)
      {
         ///Set up a string tokeniser on each line
         StringTokenizer st = new StringTokenizer(rd,"*");
         //Get the details from the line
         String url = st.nextToken();
         String details = st.nextToken();
         String lastModified = st.nextToken();
         count++;
         //Create and store a LinkInformation object
         linkHolder[linkCount] = new LinkInformation(url,details, lastModified);
         linkCount++;
      }
      messages.append(count+ " links added\n");
      br.close();
   }
   catch(Exception e)
      {messages.append("Problem loading links file "+e);};
   setSize(700,400);
}

public void actionPerformed(ActionEvent ae)
{
   if(ae.getSource()==goButton)
   {
      //Go button clicked
      int count =0;
      int changedLinkCount =0;
      changedLinks.setText("");
      //Iterate thorugh link information objects
      while(count<linkCount)
      {
         LinkInformation linkInf = linkHolder[count];
         String url = linkInf.getUrl();
         try
         {
            currentChecking.setText("Checking  "+linkInf.getDetails());
            //Establish a URL connection
            URL connection = new URL(url);
            //Open it
            URLConnection urlConn = connection.openConnection();
            //Get last modified time
            String lastModTime = urlConn.getLastModified()+"";
            //Check if there has been a modification
            if(!(lastModTime).equals(linkInf.getLastModified()))
            {
               //There has been a modification list it on the text area
               changedLinkCount++;
               linkInf.setLastModified(lastModTime);
               changedLinks.append(linkInf.getDetails()+"\n");
            }
            count++;
         }
         catch
         (Exception e)
            {messages.append("malformed URL "+ url+"\n");}
      }
      if(changedLinkCount==0)
      {
         messages.append("There were no links changed\n");
         currentChecking.setText("");
     }
   }
   if (ae.getSource()==quitButton)
   {
      try
        {
            //Quit button clicked
            fr.close();
            fw = new FileWriter("links.txt");
            PrintWriter pw = new PrintWriter(fw, true);
            int count =0;
            //Write information back to text file holding link details
            //This will include last modified date
            while(count<linkCount)
            {
               LinkInformation lnf = linkHolder[count];
               pw.println(lnf.getUrl()+"*"+lnf.getDetails()+
                          "*"+lnf.getLastModified());
               count++;
            }
            pw.close();
            fw.close();
         }
         catch(Exception e)
            {System.out.println("Problem closing file\n"+e);};
         System.exit(0);
  }
}

}