package linksales;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.util.*;

public class SalesServletSolution extends HttpServlet {

private static final String CONTENT_TYPE = "text/html";
private SaleCollection salesColl;     //Contains sales data
private Random randGenerator;         //Used to generate random PINs

//Initialize global variables
public void init(ServletConfig config) throws ServletException
{
    super.init(config);
    randGenerator =new Random();
    salesColl = new SaleCollection("SoftwareSales");
    System.out.println("Sales database set up");
}

//Process the HTTP Post request
public void doPost(HttpServletRequest request, HttpServletResponse response)
       throws ServletException, IOException
{
    //Pick up details from form
    String versionRequested=request.getParameter("version");
    String emailAddress= request.getParameter("emailAddress");
    String pinNo = generatePIN();
    //insert new sale into collection of sales
    salesColl.insertSale(new Sale(emailAddress, versionRequested,pinNo));
    PrintWriter out = response.getWriter();
    //Send confirming reply
    response.setContentType(CONTENT_TYPE);
    out.println("<html>");
    out.println("<head><title>SalesReply</title></head>");
    out.println("<body>");
    out.println("<p>You have now bought your software. The PIN number for");
    out.println("you to use is "+pinNo+ "</p>");
    out.println("</body></html>");
  }

  //Clean up resources
public void destroy()
{
   Enumeration en = salesColl.getAllSales();
   //Display database state  on System.out for checking
   Sale retrievedSale;
   while(en.hasMoreElements())
   {
      retrievedSale = (Sale) en.nextElement();
      System.out.println(retrievedSale);
   }
   salesColl.close();
}

public String generatePIN()
{
   //Generate a six digit PIN number,do not worry about generating duplicates
   int numGenerated =randGenerator.nextInt();
   String returnValue=null;
   //Convert the number to one which is less than a million
   numGenerated %=1000000;
   //It could be negative so handle this case
   if(numGenerated<0) numGenerated = -numGenerated;
   //Pad out leading zeroes, done in an inelegant way but what the
   //heck its readable
   if(numGenerated<10)returnValue = "00000"+numGenerated;
   else
      if(numGenerated<100)returnValue = "0000"+numGenerated;
      else
         if(numGenerated<1000)returnValue = "000"+numGenerated;
         else
            if(numGenerated<10000)returnValue = "00"+numGenerated;
            else
               if(numGenerated<100000)returnValue = "0"+numGenerated;
               else
                  returnValue = numGenerated+"";
   return returnValue;
}

}