package linkchecking;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;



public class LinkCheckFrame extends Frame implements ActionListener{

private Button goButton,    //Starts processing off
               quitButton;  //Quits the application

private TextField messages; //Sends messages to the user

private Panel buttonPanel,  //Holds the buttons
              messagePanel; //Holds messages and label

private LinkCollection links;  //Holds links to be checked

private FileOutputStream fo;   //For generated XMl source
private PrintWriter pw;

public LinkCheckFrame(String title)
{
  super(title);
  links = new LinkCollection("LinksData");
  this.setLayout(new FlowLayout());
  buttonPanel = new Panel();
  messagePanel = new Panel();
  goButton = new Button("Go");
  quitButton = new Button("Quit");
  buttonPanel.add(goButton);
  buttonPanel.add(quitButton);
  messages = new TextField(35);
  add(buttonPanel);
  messagePanel.add(new Label("Messages"));
  messagePanel.add(messages);
  add(messagePanel);
  goButton.addActionListener(this);
  quitButton.addActionListener(this);
  try
  {
     fo = new FileOutputStream("links.txt");
     pw = new PrintWriter(fo, true);
  }
  catch(Exception e)
     {System.out.println("Problem setting up XML file");}
}


public static void main(String[] args)
{
   LinkCheckFrame lFrame = new LinkCheckFrame("Checker");
   lFrame.setSize(400,150);
   lFrame.setVisible(true);
}

public void actionPerformed(ActionEvent ae)
{
   if(ae.getSource()==goButton)
      //Starts the link checking process
      linkCheck();
   if(ae.getSource()==quitButton)
      //Quits the program
      {
      try
      {
         fo.close();
         pw.close();
      }
      catch(Exception e)
         {System.out.println("Problem closing XML file");}
      System.exit(0);
      }
  }

public void linkCheck()
{
   //Iterates over each link checking it. If a link is dead
   //an XML-based entry is written to a text file
   Link retrievedLink;
   //Get and enumeration to the links
   Enumeration num = links.getAllLinks();
   int linkCount = 0,   //Count of links examined
   deadLinkCount = 0;   //Count of dead links
   URLTest uTest;
   String urlRetrieved;
   int status;
   //Write header text for XML document
   pw.println("<?xml version = \"1.0\" standalone = \"no\" ?>");
   pw.println("<!DOCTYPE LINKCOLLECTION SYSTEM \"linkdefns.txt\" >");
   pw.println("<LINKCOLLECTION>");
   while(num.hasMoreElements())
   {
      //Get next link
      retrievedLink  = (Link)num.nextElement();
      linkCount++;
      try
      {
         //Get URL of link
         urlRetrieved = retrievedLink.getLinkAddress()+"";
         uTest = new URLTest(urlRetrieved);
         messages.setText("Checking "+urlRetrieved);
         //Check if the link is dead
         status = uTest.testURL();
         if(status == URLTest.resourceNotFound||status == URLTest.siteNotFound)
         {
            //Now write the XML source for each dead link
            pw.println("<LINKBREAK>");
            pw.print("<URL>"+urlRetrieved);
            pw.println("</URL>");
            pw.print("<DESCRIPTION>");
            pw.print(retrievedLink.getTextDescription());
            pw.println("</DESCRIPTION>");
            pw.print("<EMAIL>");
            pw.print(retrievedLink.getEmailAddress());
            pw.println("</EMAIL>");
            pw.println("</LINKBREAK>");
            deadLinkCount++;
         }
      }
      catch(Exception e)
        {System.out.println("Problem forming a URL"+e);}
   }
   pw.println("</LINKCOLLECTION>");
   messages.setText("Checking complete "+deadLinkCount+ " dead links found");
}

}