package checksoftware;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;


public class UserFrame extends Frame implements ActionListener{


private  Button startButton,        //Starts the search for links
                addButton,          //Adds a URL
                removeButton,       //Removes a URL
                quitButton;         //Quits the application

private TextField messages,      //Sends messages to the user
                  liveLinkCount, //Count of links found
                  deadLinkCount, //Count of dead links found
                  urlName;       //URL to be added

private TextArea deadLinkDisplay;   //Displays identity of dead links
private java.awt.List currentURLs;  //Displays URLs in database

private Panel topPanel, bottomPanel, topLeftPanel,
        topRightPanel, buttonPanel;

private int goodLinks, //Count of links detected
            badLinks;  //Count of dead links

//The vector holds the URLs that are to be checked. It is set up from a file
//url.obj if the file exists, if it doesn't it is set up as an empty vector
private Vector urlStore;

UserFrame(String title)
{
   super("LinkChecker");
   //Starts checking process
   startButton = new Button("Start");
   //Adds a URL
   addButton = new Button("Add");
   //removes a URL
   removeButton = new Button("Remove");
   //Quits dialogue
   quitButton = new Button("Quit");
   //Holds messages from tool
   messages = new TextField(4);
   //Holds name of URL to be added
   urlName = new TextField("Type in the URL name to be added here",25);
   //Holds number of live links
   liveLinkCount = new TextField("0",4);
   //Holds number of dead links
   deadLinkCount = new TextField("0",4);
   currentURLs = new java.awt.List(10);
   deadLinkDisplay = new TextArea(10, 35);
   //Set up display
   setLayout(new GridLayout(2,2));
   bottomPanel = new Panel();
   bottomPanel.setLayout(new GridLayout(5,1));
   topPanel = new Panel();
   buttonPanel = new Panel();
   buttonPanel.add(startButton);
   buttonPanel.add(addButton);
   buttonPanel.add(removeButton);
   buttonPanel.add(quitButton);
   bottomPanel.add(buttonPanel);
   bottomPanel.add(new Label("URL name to be added"));
   bottomPanel.add(urlName);
   bottomPanel.add(new Label("Messages"));
   bottomPanel.add(messages);
   topLeftPanel = new Panel();
   topRightPanel = new Panel();
   topLeftPanel.setLayout(new FlowLayout());
   topRightPanel.setLayout(new FlowLayout());
   topLeftPanel.add(new Label("Current URLs"));
   topLeftPanel.add(currentURLs);
   topLeftPanel.add(new Label("Found dead links"));
   topLeftPanel.add(deadLinkDisplay);
   topRightPanel.add(new Label("Dead link count"));
   topRightPanel.add(deadLinkCount);
   topRightPanel.add(new Label("Live link count"));
   topRightPanel.add(liveLinkCount);
   topPanel.setLayout(new FlowLayout());
   topPanel.add(topRightPanel);
   topPanel.add(topLeftPanel);
   add(topPanel);
   add(bottomPanel);

   //Add listeners
   quitButton.addActionListener(this);
   addButton.addActionListener(this);
   removeButton.addActionListener(this);
   startButton.addActionListener(this);

   if(new File("url.obj").exists())
   {
      //File already set up with URLs
      try
      {
         FileInputStream fi = new FileInputStream("url.obj");
         ObjectInputStream objIn = new ObjectInputStream(fi);
         urlStore = (Vector)objIn.readObject();
      }
      catch(Exception e)
         {messages.setText("Problem with URL file");}
   }
   else
   {
      //File does not already exist, just create the vector
      //that holds the strings representing the URLs
      urlStore = new Vector(100);
   }
   //Set number of good and bad links ready for checking
   badLinks = goodLinks =0;
   messages.setText(""+urlStore.size()+" Links loaded");
   //Populate the frame with list of current links in database
   populateList();
}

 public void populateList()
 {
   //Populates the list with current URLs
   currentURLs.removeAll();
   Enumeration enum = urlStore.elements();
   String nextURL;
   //Iterate thorugh vector extracting the URLs
   while(enum.hasMoreElements())
   {
      nextURL = (String) enum.nextElement();
      currentURLs.add(nextURL);
   }
}

public void actionPerformed(ActionEvent ae)
{
   if(ae.getSource()==quitButton)
      //User quits
      quitAction();
   if(ae.getSource()==addButton)
      //User adds a URL
      addAction();
   if(ae.getSource()==removeButton)
      //User removes a URL
      removeAction();
   if(ae.getSource()==startButton)
      //User removes a URL
      startAction();
}

public static void main(String[] args)
{
   //Main method
   UserFrame uf = new UserFrame("Link Checking");
   uf.setSize(800,550);
   uf.setVisible(true);
}

//Processing methods follow from here

public void startAction()
{
   // Insert required code her
}


public void quitAction()
{
   //User quits
   //First write the URLs to a file
   try
   {
      FileOutputStream fo = new FileOutputStream("url.obj");
      ObjectOutputStream os = new ObjectOutputStream(fo);
      os.writeObject(urlStore);
    }
    catch(Exception e)
       {messages.setText("Problem writing to URL file");
       };
    //Then exit
    System.exit(0);
}

public void addAction()
{
   //User adds a URL
   String addedURL = urlName.getText();
   urlStore.add(addedURL);
   currentURLs.add(addedURL);
   messages.setText("URL added");
   urlName.setText("");
}

public void removeAction()
{
   //User removes a URL
   String selected = currentURLs.getSelectedItem();
   if(selected==null)
   //URL needs to be selected
   messages.setText("You need to select a URL");
   urlStore.remove(selected);
   //Adjust list
   populateList();
}

}