package salesreport;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;
import salesserver.*;
import java.rmi.server.*;
import java.rmi.*;


public class ClientFrameSolution extends Frame implements ActionListener {

private Button quitButton,        //Quits the client
               reportButton,      //Produces report on sales
               findButton;        //Finds details on one sale

private java.awt.List userList;   //Lists email addresses of users
                                  //have bought software

private TextField pin,            //Holds PIN number of a customer
                  versionBought;   //Holds version bought of the software

private Panel textPanel,          //Contains text elements
              buttonPanel;        //Contains buttons


private SaleCollection collection;

ClientFrameSolution(String title)
{
   super(title);
   setLayout(new GridLayout(2,2));
   quitButton = new Button("Quit");
   reportButton = new Button("Report");
   findButton = new Button("Find");
   buttonPanel = new Panel();
   buttonPanel.add(quitButton);
   buttonPanel.add(reportButton);
   buttonPanel.add(findButton);
   add(buttonPanel);
   pin = new TextField(8);
   versionBought = new TextField(14);
   textPanel = new Panel();
   textPanel.setLayout(new GridLayout(4,1));
   textPanel.add(new Label("PIN"));
   textPanel.add(pin);
   textPanel.add(new Label("Version bought"));
   textPanel.add(versionBought);
   add(textPanel);
   userList = new java.awt.List(8);
   add(userList);
   setSize(450,300);
   setVisible(true);
   //register buttons
   quitButton.addActionListener(this);
   reportButton.addActionListener(this);
   findButton.addActionListener(this);
   try
   {
      //Get remote reference to database of sales
      String uRL = "rmi://localhost/Sales";
      collection = (SaleCollection) Naming.lookup(uRL);
   }
   catch (Exception re)
     {System.out.println("Trouble initially contacting the server"+re);}
   //Place all the email addresses in the list box
   Vector v =null;
   try
   {
      v = collection.getAllSales();
   }
   catch(Exception re)
      {System.out.println("Trouble contacting the server"+re);}
   Sale retrievedSale;
   Enumeration en = v.elements();
   while(en.hasMoreElements())
   {
      retrievedSale = (Sale)en.nextElement();
      userList.add(retrievedSale.getEmailAdress());
   }
}

public void actionPerformed(ActionEvent ae)
{
   //Button processing
   if(ae.getSource()==quitButton)
      //User quits
      System.exit(0);
   if(ae.getSource()==reportButton)
      //User requests a report
      makeReport();
   if(ae.getSource()==findButton)
      //User requests customer details
      getCustomerDetails();
}


public void makeReport()
{
   //Constructs a file report.txt containing sales details
   PrintWriter pw=null;
   try
   {
      pw = new PrintWriter
         (new FileOutputStream("report.txt"),true);
   }
   catch(Exception e)
      {System.out.println("Problem opening report file");}
   //Enumerate the customers
   Vector v =null;
   try
   {
      v = collection.getAllSales();
   }
   catch(RemoteException re)
     {System.out.println("Trouble contacting the server");}
   Enumeration en = v.elements();
   Sale retrievedSale;
   //Process each customer writing their details to a report file
   while(en.hasMoreElements())
   {
      retrievedSale = (Sale) en.nextElement();
      pw.println(retrievedSale);
   }
   pw.close();
}

public void getCustomerDetails()
{
   //Retrieve customer details for customer whose name is highlighted
   Sale retrievedSale=null;
   try
   {
      retrievedSale =collection.findSale(userList.getSelectedItem());
   }
   catch(RemoteException re)
      {System.out.println("Trouble contacting the server");};
   //Set the text fields
   pin.setText(retrievedSale.getPinNumber());
   versionBought.setText(retrievedSale.getSoftwareVersion());
}


public static void main(String[] args)
{
   ClientFrameSolution cf = new ClientFrameSolution("RMIClient");
}

}