package linkmaintenance;

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.util.*;
import java.net.*;

public class LinkApplet extends Applet implements ActionListener
{
//*******************************************
//Edit following code line for exercise to be
//LinkCollection links;
//*******************************************
LinkCollectionSolution links;
boolean isStandalone = false;
Button addButton,         //Button for adding a URL
       removeButton,      //Button for removing a URL
       findButton,        //Button for finding text
                          //associated with URL
       displayButton;     //Button for displaying URLs
                          //associated with a user

TextField emailAddress,    //Holds the email address of the user
          password,        //Holds the password, not used in this code
          url,             //Holds the URL
          textDescription; //Holds the text description of a URL for input

TextArea textDescriptionArea,   //Displays the output text description
         messages;              //Displays any messages to the user

java.awt.List currentURLs;            //Displays current URLs retrieved for user

Panel buttonPanel,          //Holds the buttons
      displayPanel,         //Holds the display areas
      textFieldPanel,       //Holds all the text fields
      messagePanel;         //Holds messages

//Get a parameter value
public String getParameter(String key, String def)
{
   return isStandalone ? System.getProperty(key, def) :
   (getParameter(key) != null ? getParameter(key) : def);
}

//Construct the applet
public LinkApplet()
{
   setLayout(new GridLayout(2,3));
   //Set up visual interface
   addButton = new Button("Add");
   removeButton = new Button("Remove");
   findButton = new Button("Find");
   displayButton = new Button("Display");
   buttonPanel = new Panel();
   buttonPanel.add(addButton);
   buttonPanel.add(removeButton);
   buttonPanel.add(findButton);
   buttonPanel.add(displayButton);
   emailAddress = new TextField(25);
   password = new TextField(25);
   password.setEchoChar('*');   //Echo character for this field
   url = new TextField(25);
   textDescription = new TextField(30);
   textFieldPanel = new Panel();
   textFieldPanel.setLayout(new GridLayout(8,1));
   textFieldPanel.add(new Label("Email address"));
   textFieldPanel.add(emailAddress);
   textFieldPanel.add(new Label("Password"));
   textFieldPanel.add(password);
   textFieldPanel.add(new Label("URL"));
   textFieldPanel.add(url);
   textFieldPanel.add(new Label("Description of URL"));
   textFieldPanel.add(textDescription);
   displayPanel = new Panel();
   currentURLs = new java.awt.List(8);
   textDescriptionArea = new TextArea(20,15);
   displayPanel.setLayout(new GridLayout(4,1));
   displayPanel.add(currentURLs);
   displayPanel.add(new Label("Current URLs"));
   displayPanel.add(textDescriptionArea);
   displayPanel.add(new Label("Description of URL"));
   add(textFieldPanel);
   add(new Label("")); //Hack for spacing
   add(displayPanel);
   add(buttonPanel);
   messagePanel = new Panel();
   messages = new TextArea(5,30);
   messagePanel.add(new Label("Messages"));
   messagePanel.add(messages);
   add(messagePanel);

   //Register buttons so the applet listens to them
   addButton.addActionListener(this);
   removeButton.addActionListener(this);
   findButton.addActionListener(this);
   displayButton.addActionListener(this);

   //Set up links database

   //*******************************************
   //Edit following code line for exercise to be
   //links = new LinkCollection("LinksData")
   //*******************************************
   links = new LinkCollectionSolution("LinksData");
}

//Initialize the applet
public void init()
{
   try
   {
      jbInit();
   }
   catch(Exception e)
   {
      e.printStackTrace();
   }
}


public void actionPerformed(ActionEvent ae)
{
   //Processing of button clicks
   if(ae.getSource()==addButton)
      //URL to be added to database
      add();

   if(ae.getSource()==removeButton)
      //URL to be added to database
      remove();

   if(ae.getSource()==findButton)
      //Descriptive text to be retrieved for a URL
      retrieveText();

   if(ae.getSource()==displayButton)
      //Descriptive text to be retrieved for a URL
      display();
}

//Processing methods

public void add()
{
   //Adds a link to the link database
   try
   {
      Link newLink = new Link
          (new URL(url.getText()), textDescription.getText(),
                   emailAddress.getText());
      links.addLink(newLink);
      messages.setText("Link added");
   }
   catch(Exception e){messages.setText("You have to provide a valid URL");}
}

public void remove()
{
   //Removes a link from the link database
   //First get the email address and URL to be removed
   String eAddress = emailAddress.getText();
   String urlValue = currentURLs.getSelectedItem();
   try
   {
      //Now add the link
      links.deleteLink(eAddress, new URL(urlValue));
      currentURLs.remove(urlValue);
      messages.setText("Link removed");
   }
   catch(Exception e)
   {System.out.println("Problem with identifying link");}

}


public void retrieveText()
{
   //Retrieves the text associated with a link and displays it

   //First get the user email address
   String eAddress = emailAddress.getText();
   //Next the URL, the user will have highlighted it
   String urlIdentity=currentURLs.getSelectedItem();
   //Retrieve the link
   Link retrievedLink = null;
   try
   {
     retrievedLink =links.getLink
                             (eAddress, new URL(urlIdentity));
   }
   catch(Exception e)
     {System.out.println("URL not valid");};
   textDescriptionArea.setText(retrievedLink.getTextDescription());
}


public void display()
{
   //Retrieves all the URLs associated with a particular user
   //and then displays them

   //First get the user email address
   currentURLs.removeAll();
   String eAddress = emailAddress.getText();
   Enumeration e =links.getLinksForUser(eAddress);
   //Move thorugh the links displaying them for the user
   while(e.hasMoreElements())
   {
      Link next = (Link) e.nextElement();
      currentURLs.add(next.getLinkAddress()+"");
   }
}

public void stop()
{
   links.close();
}

//Component initialization
private void jbInit() throws Exception
{
}

}